from rocolib.api.components.Component import Component
from rocolib.api.Function import Function

# ESP3 STACK WITH PWM SERVO FEATHERWING
c = Component()

c.addSubcomponent("holder", "SimpleRectBeam")

# Dimensions of the ESP32 Stack
c.addParameter("length", 60, paramType="length")

c.addParameter("brains", "esp32stack", paramType="dimension")
c.addConstraint(("holder", "length"), "length")
c.addConstraint(("holder", "depth"), "brains", "getDim(x, 'height')")
c.addConstraint(("holder", "width"), "brains", "getDim(x, 'width')")

# This parameter will change when the dimensions of the car or vehicle is changed
# so that it would not affect the ESP32 stack holder
c.addSubcomponent("header", "Header")


def getBrainParameter(p):
    return "brains", "getDim(x, '%s')" % p


# OLED at the top
c.addConstraint(("header", "nrows"), "brains", "getDim(x, 'nrows')")
c.addConstraint(("header", "ncols"), "brains", "getDim(x, 'ncols')")
c.addConstraint(("header", "rowsep"), "brains", "getDim(x, 'rowsep')")
c.addConstraint(("header", "colsep"), "brains", "getDim(x, 'colsep')")

# Holes for servo and power supply
c.addParameter("dy1", 18, parameterType="length")
c.addSubcomponent("servohole0", "Cutout")
c.addConstraint(("servohole0", "dy"), "brains", "getDim(x, 'height')/1.75")
c.addConstraint(("servohole0", "dx"), "dy1", "x-5")

c.addConnection(("holder", "face0"),
                ("header", "decoration"),
                mode="hole", offset=Function(params=("length", "brains"), fnstring="(0, 0)"))

c.addConnection(("holder", "face2"),
                ("header", "decoration"),
                mode="hole", offset=Function(params=("length", "brains"), fnstring="(0, 0)"))

c.addConnection(("holder", "face3"),
                ("servohole0", "decoration"),
                mode="hole", rotate=True,
                offset=Function(params=("brains", "length"), fnstring="(getDim(x[0], 'height') * -0.06, x[1] * 0.32)"))

c.addSubcomponent("powerhole", "Cutout")
c.addConstraint(("powerhole", "dy"), "brains", "getDim(x, 'height')/1.75")
c.addConstraint(("powerhole", "dx"), "dy1")

c.addConnection(("holder", "face1"),
                ("powerhole", "decoration"),
                mode="hole", rotate=True,
                offset=Function(params=("brains", "length"), fnstring="(getDim(x[0], 'height') * 0.15, x[1] * 0.25)"))

c.inheritAllInterfaces("holder", prefix=None)

c.toLibrary("SubESP32Stack")
