from rocolib.api.ports import Port
from rocolib.utils.utils import prefix as prefixString

class EdgePort(Port):
  def __init__(self, parent, edges, lengths):
    Port.__init__(self, parent, {})
    if isinstance(edges, str) or not hasattr(edges, "__iter__"):
        edges = [edges]
    if isinstance(lengths, str) or not hasattr(lengths, "__iter__"):
        lengths = [lengths]
    if len(edges) != len(lengths):
        raise ValueError("Need one-to-one mapping of edges to lengths")
    self.edges = edges
    self.lengths = lengths

  def getEdges(self):
    return self.edges

  def getParams(self):
    return self.lengths

  def prefix(self, prefix=""):
    self.edges = [prefixString(prefix, e) for e in self.edges]

  def canMate(self, otherPort):
    try:
      return len(self.getEdges()) == len(otherPort.getEdges())
    except AttributeError:
      return False

  def toString(self):
    return str(self.getEdges())
