from rocolib.api.components.Component import Component
from rocolib.api.Function import Function

c = Component()

c.addSubcomponent("boat", "BoatBase", inherit=True, prefix=None)
c.inheritAllInterfaces("boat")
c.addSubcomponent("rudder", "BottomServoMount", inherit=True)

c.addConstraint(("rudder", "width"), "boat.width")
c.addConstraint(("rudder", "depth"), "boat.depth")

c.addParameter("topDistance", 50, paramType="length")
c.addParameter("botDistance", 50, paramType="length")

for i in range(2):
    c.addSubcomponent("split%d" %i, "SplitEdge")
    c.addConstraint(("split%d" %i, "toplength"), "boat.length", "(x,)")

c.addConstraint(("split0", "botlength"), ("topDistance", "botDistance"), "(x[0]-12, 24, x[1]-12)")
c.addConstraint(("split1", "botlength"), ("topDistance", "botDistance"), "(x[1]-12, 24, x[0]-12)")

c.addConnection(("boat", "portedge"), ("split0", "topedge0"))
c.addConnection(("boat", "staredge"), ("split1", "topedge0"))

c.addConnection(("rudder","rightArmInterface"), ("split0", "botedge1"), angle=-180)
c.addConnection(("rudder","leftArmInterface"), ("split1", "botedge1"), tabWidth=5)

c.inheritInterface("topPort", ("split0", "botedge0"))
c.inheritInterface("botPort", ("split0", "botedge2"))
c.inheritInterface("topStar", ("split1", "botedge2"))
c.inheritInterface("botStar", ("split1", "botedge0"))

c.toLibrary("BoatWithBottomServo")
