from rocolib.api.components.Component import Component

c = Component()

c.addParameter("width", 90, paramType="length")
c.addParameter("depth", 70, paramType="length")

c.addSubcomponent("boat", "BoatBase", inherit=True)
c.addSubcomponent("lServoMount", "SideServoMount", inherit=("depth","length"))
c.addSubcomponent("rServoMount", "SideServoMount", inherit=("depth","length"))

c.addConstraint(("boat", "boat.width"), "width")
c.addConstraint(("boat", "boat.depth"), "depth")

#topDistance and botDistance (and servoMount length) determine the dimensions of the boat hull
c.addParameter("topDistance", 80, paramType="length", minValue=0) #servo mount length above the connecting edge
c.addParameter("botDistance", 80, paramType="length", minValue=73) #servo mount length below the connecting edge

c.addConstraint(("boat","boat.length"), ("topDistance", "botDistance", "lServoMount.depth"), "x[0] + x[1] + x[2]")

c.addSubcomponent("lsplit", "SplitEdge")
c.addConstraint(("lsplit", "toplength"), ("topDistance", "botDistance", "lServoMount.depth"), "(x[0] + x[1] + x[2],)")
c.addConstraint(("lsplit", "botlength"), ("topDistance", "botDistance", "lServoMount.depth"), "(x[0], x[2], x[1])") #but the value of the new component's boat.length parameter is completely disconnected from the value of the boat component's boat.length parameter
#
c.addSubcomponent("rsplit", "SplitEdge")
c.addConstraint(("rsplit", "toplength"), ("topDistance", "botDistance", "rServoMount.depth"), "(x[0] + x[1] + x[2],)")
c.addConstraint(("rsplit", "botlength"), ("topDistance", "botDistance", "rServoMount.depth"), "(x[1], x[2], x[0])") #but the value of the new component's boat.length parameter is completely disconnected from the value of the boat component's boat.length parameter

c.addConnection(("lsplit", "botedge1"), ("lServoMount", "rightInterface"), angle=180) #both face the same direction
c.addConnection(("rsplit", "botedge1"), ("rServoMount", "leftInterface"), angle=180)

#Bottom belt
c.addSubcomponent("lservodown", "Rectangle")
c.addConstraint(("lservodown", "w"), "lServoMount.depth")
c.addConstraint(("lservodown", "l"), (("depth"), "lServoMount.length"), "x[0] - x[1]") #DEPTH OF BOAT - 3 for the tab

c.addSubcomponent("lservoacross", "Rectangle")
c.addConstraint(("lservoacross", "w"), "lServoMount.depth")
c.addConstraint(("lservoacross", "l"), ("width"), "x * 0.5") #DEPTH OF BOAT - 3 for the tab

c.addConnection(("lservodown", "r"),("lservoacross", "r"), angle=-90)
c.addConnection(("lservodown", "l"), ("lServoMount", "leftInterface"))

c.addSubcomponent("rservodown", "Rectangle")
c.addConstraint(("rservodown", "w"), "rServoMount.depth")
c.addConstraint(("rservodown", "l"), (("depth"), "rServoMount.length"), "x[0] - x[1]") #DEPTH OF BOAT - 3 for the tab

c.addSubcomponent("rservoacross", "Rectangle")
c.addConstraint(("rservoacross", "w"), "rServoMount.depth")
c.addConstraint(("rservoacross", "l"), ("width"), "x * 0.5") #DEPTH OF BOAT - 3 for the tab

c.addConnection(("rservodown", "r"),("rservoacross", "r"), angle=-90)
c.addConnection(("rservodown", "l"), ("rServoMount", "rightInterface"))

c.addConnection(("lservoacross", "l"), ("rservoacross", "l"), tabWidth=5)
#
c.addConnection(("boat", "portedge"), ("lsplit", "topedge0"))
c.addConnection(("boat", "staredge"), ("rsplit", "topedge0"))

c.inheritInterface("topPort", ("lsplit", "botedge0"))
c.inheritInterface("botPort", ("lsplit", "botedge2"))
c.inheritInterface("topStar", ("rsplit", "botedge2"))
c.inheritInterface("botStar", ("rsplit", "botedge0"))

c.toLibrary("BoatWithServoMount")
