from rocolib.api.components.Component import Component

#ESP3 STACK WITH PWM SERVO FEATHERWING
c = Component()

c.addSubcomponent("boat", "BoatBase", inherit=True)
c.inheritAllInterfaces("boat")

c.addParameter("toplength", 180, paramType="length")
c.addParameter("botlength", 180, paramType="length")
c.addParameter("width", 90, paramType="length")
c.addParameter("depth", 70, paramType="length")

c.addConstraint(("boat", "boat.length"), ("toplength", "botlength"), "(x[0]+x[1]+122)") #122 is length of Stack mount + length of Battery mount
c.addConstraint(("boat", "boat.width"), "width")
c.addConstraint(("boat", "boat.depth"), "depth")
# c.addConstConstraint(("boat", "stern.point"), 50)
# c.addConstConstraint(("boat", "bow.point"), 50)

c.addSubcomponent("stack", "StackMount", inherit="stack.length", prefix=None)
c.inheritAllInterfaces("stack")

c.addSubcomponent("batterymount", "BatteryMount", inherit="batterylength", prefix=None)
c.inheritAllInterfaces("batterymount")

c.addSubcomponent("portsplit", "SplitEdge", inherit=True)
c.addConstraint(("portsplit", "toplength"), ("toplength","botlength"), "(x[0]+x[1]+122,)")
c.addConstraint(("portsplit", "botlength"), ("toplength","botlength", "stack.length", "batterylength"), "((x[0]+x[1]+122)/2 - (x[2]+x[3])/2, x[2], x[3], (x[0]+x[1]+122)/2 - (x[2]+x[3])/2)")
c.addConnection(("portsplit", "botedge1"), ("stack", "leftArmInterface"))
c.addConnection(("batterymount", "leftArmInterface"), ("portsplit", "botedge2"), tabWidth=10)
c.addConnection(("boat", "portedge"), ("portsplit", "topedge0"))

c.addSubcomponent("starsplit", "SplitEdge", inherit=True)
c.addConstraint(("starsplit", "toplength"), ("toplength","botlength"), "(x[0]+x[1]+122,)")
c.addConstraint(("starsplit", "botlength"), ("toplength","botlength", "stack.length", "batterylength"), "((x[0]+x[1]+122)/2 - (x[2]+x[3])/2, x[2], x[3], (x[0]+x[1]+122)/2 - (x[2]+x[3])/2)")
c.addConnection(("starsplit", "botedge2"), ("stack", "rightArmInterface"), tabWidth=10)
c.addConnection(("batterymount", "rightArmInterface"), ("starsplit", "botedge1"), tabWidth=10)
c.addConnection(("boat", "staredge"), ("starsplit", "topedge0"))

c.inheritInterface("porttopsplit", ("portsplit", "botedge0"))
c.inheritInterface("portbotsplit", ("portsplit", "botedge3"))
c.inheritInterface("startopsplit", ("starsplit", "botedge3"))
c.inheritInterface("starbotsplit", ("starsplit", "botedge0"))

c.toLibrary("BoatWithStackBattery")
