from sympy import symbols

dims = {}

def isDim(obj):
    return obj in dims

def getDim(obj, param):
    return dims[obj][param]

'''
Brain dimension parameters:
      params.setdefault("length")
      params.setdefault("width")
      params.setdefault("height")

      params.setdefault("nrows")
      params.setdefault("ncols")
      params.setdefault("rowsep")
      params.setdefault("colsep")
'''
dims["proMini"] = { "type" : "brains",
    "length"    : 39,
    "width"     : 19,
    "height"    : 9,
    "nrows"     : 12,
    "ncols"     : 2,
    "rowsep"    : 0.1 * 25.4,
    "colsep"    : 0.6 * 25.4,
}

dims["nodeMCU"] = { "type" : "brains",
    "length"    : 59.5,
    "width"     : 44,
    "height"    : 13,
    "nrows"     : 15,
    "ncols"     : 2,
    "rowsep"    : 0.1 * 25.4,
    "colsep"    : 0.9 * 25.4,
}

#48 before
dims["esp32stack"] = { "type" : "brains",
    "length"    : 51,
    "width"     : 24,
    "height"    : 36,
    "nrows"     : 16,
    "ncols"     : 2,
    "rowsep"    : 2.5,
    "colsep"    : 20,
}


'''
Servo dimension parameters:

             |<-G->|
^      =====v===== { H
E          _I_
v ________| | |_____
  ^ |       |<-F->|<> D
  | |             |
  B | <--- A ---> |
  | | (X) C       |
  v |_____________|

A : motorlength
B : motorheight
C : motorwidth
D : shoulderlength

E : hornheight
F : hornoffset

G : hornlength
H : horndepth

        params.setdefault("motorlength")
        params.setdefault("motorwidth")
        params.setdefault("motorheight")
        params.setdefault("shoulderlength", 0)

        params.setdefault("hornheight", 0)
        params.setdefault("hornoffset", 0)

        params.setdefault("hornlength", 0)
        params.setdefault("horndepth", 0)

If horn is not symmetric?

        params.setdefault("rhornlength", 0)
        params.setdefault("lhornlength", 0)
        if name == "hornlength":
            self.setParameter("rhornlength", val)
            self.setParameter("lhornlength", val)

Should horn be a different object?

'''

dims["s4303r"] = { "type" : "servo",
    "motorlength"   : 31,
    "motorwidth"    : 17,
    "motorheight"   : 29,
    "shoulderlength": 10,
    "hornlength"    : 38,
    "hornheight"    : 14,
    "hornoffset"    : 7,
    "horndepth"     : 2,
}

dims["tgy1370a"] = { "type" : "servo",
    "motorlength"   : 20,
    "motorwidth"    : 9,
    "motorheight"   : 14,
    "shoulderlength": 4,
    "hornlength"    : 7,
    "hornheight"    : 10,
    "hornoffset"    : 4,
    "horndepth"     : 2,
}

dims["fs90r"] = { "type" : "servo",
    "motorlength"   : 23,
    "motorwidth"    : 13,
    "motorheight"   : 19,
    "shoulderlength": 5,
    "hornlength"    : 10,
    "hornheight"    : 16,
    "hornoffset"    : 8,
    "horndepth"     : 2,
}

l, w, h, r, c, rs, cs = symbols("brainLength brainWidth brainHeight brainNRows brainNCols brainRowSep brainColSep", positive=True)

dims["brainSymbols"] = { "type" : "brains",
    "length"    : l,
    "width"     : w,
    "height"    : h,
    "nrows"     : r,
    "ncols"     : c,
    "rowsep"    : rs,
    "colsep"    : cs,
}

l, w, h, s, hl, hh, ho, hd = symbols("servoLength servoWidth servoHeight servoShoulder servoHornLength servoHornHeight servoHornOffset servoHornDepth", positive=True)

dims["servoSymbols"] = { "type" : "servo",
    "motorlength"   : l,
    "motorwidth"    : w,
    "motorheight"   : h,
    "shoulderlength": s,
    "hornlength"    : hl,
    "hornheight"    : hh,
    "hornoffset"    : ho,
    "horndepth"     : hd,
}
